@@ -12,7 +12,10 @@ TODO: Refactor to remove functions that are just 2-lines of code.
 For example, many function's logic essentially consists in creating the layer name.
 We could have a function that returns the layer name, and then other functions expect the layer name.
 """
+import inspect
+import json
 import os
+import warnings
 from pathlib import Path
 from typing import Iterable, Optional, Sequence, Tuple, Union
 from urllib.parse import urljoin
@@ -30,11 +33,18 @@ try:
     from owslib.wcs import WebCoverageService
     from owslib.wfs import WebFeatureService
     from shapely.geometry import Point, shape
-
 except (ImportError, ModuleNotFoundError) as e:
     msg = gis_import_error_message.format(Path(__file__).stem)
     raise ImportError(msg) from e
 
+try:
+    from owslib.fes2 import Intersects
+    from owslib.gml import Point as wfs_Point
+except (ImportError, ModuleNotFoundError):
+    warnings.warn("WFS point spatial filtering requires OWSLib>0.24.1.")
+    Intersects = None
+    wfs_Point = None
+
 # Do not remove the trailing / otherwise `urljoin` will remove the geoserver path.
 # Can be set at runtime with `$ env GEO_URL=https://xx.yy.zz/geoserver/ ...`.
 GEO_URL = os.getenv("GEO_URL", "https://pavics.ouranos.ca/geoserver/")
@@ -49,15 +59,23 @@ hybas_domains = {dom: hybas_dir / hybas_pat.format(dom) for dom in hybas_regions
 
 
 def _get_location_wfs(
-    coordinates: Tuple[
-        Union[int, float, str],
-        Union[str, float, int],
-        Union[str, float, int],
-        Union[str, float, int],
-    ],
-    layer: str = True,
+    bbox: Optional[
+        Tuple[
+            Union[str, float, int],
+            Union[str, float, int],
+            Union[str, float, int],
+            Union[str, float, int],
+        ]
+    ] = None,
+    point: Optional[
+        Tuple[
+            Union[str, float, int],
+            Union[str, float, int],
+        ]
+    ] = None,
+    layer: str = None,
     geoserver: str = GEO_URL,
-) -> bytes:
+) -> str:
     """Return leveled features from a hosted data set using bounding box coordinates and WFS 1.1.0 protocol.
 
     For geographic rasters, subsetting is based on WGS84 (Long, Lat) boundaries. If not geographic, subsetting based
@@ -65,8 +83,10 @@ def _get_location_wfs(
 
     Parameters
     ----------
-    coordinates : Tuple[Union[str, float, int], Union[str, float, int], Union[str, float, int], Union[str, float, int]]
+    bbox : Optional[Tuple[Union[str, float, int], Union[str, float, int], Union[str, float, int], Union[str, float, int]]]
       Geographic coordinates of the bounding box (left, down, right, up).
+    point : Optional[Tuple[Union[str, float, int], Union[str, float, int]]]
+      Geographic coordinates of an intersecting point (lon, lat).
     layer : str
       The WFS/WMS layer name requested.
     geoserver: str
@@ -78,21 +98,41 @@ def _get_location_wfs(
       A GeoJSON-encoded vector feature.
 
     """
-    wfs = WebFeatureService(url=urljoin(geoserver, "wfs"), version="1.1.0", timeout=30)
+    wfs = WebFeatureService(url=urljoin(geoserver, "wfs"), version="2.0.0", timeout=30)
+
+    if bbox and point:
+        raise NotImplementedError("Provide either 'bbox' or 'point'.")
+    if bbox:
+        kwargs = dict(bbox=bbox)
+    elif point:
+        # FIXME: Remove this once OWSlib > 0.24.1 is released.
+        if not Intersects and not wfs_Point:
+            raise NotImplementedError(
+                f"{inspect.stack()[1][3]} with point filtering requires OWSLib>0.24.1.",
+            )
+
+        p = wfs_Point(
+            id="feature",
+            srsName="http://www.opengis.net/gml/srs/epsg.xml#4326",
+            pos=point,
+        )
+        f = Intersects(propertyname="the_geom", geometry=p)
+        intersects = f.toXML()
+        kwargs = dict(filter=intersects)
+    else:
+        raise ValueError()
+
     resp = wfs.getfeature(
-        typename=layer,
-        bbox=coordinates,
-        srsname="urn:x-ogc:def:crs:EPSG:4326",
-        outputFormat="application/json",
+        typename=layer, outputFormat="application/json", method="POST", **kwargs
     )
 
-    data = resp.read()
+    data = json.loads(resp.read())
     return data
 
 
 def _get_feature_attributes_wfs(
     attribute: Sequence[str],
-    layer: str,
+    layer: str = None,
     geoserver: str = GEO_URL,
 ) -> str:
     """Return WFS GetFeature URL request for attribute values.
@@ -160,7 +200,7 @@ def _filter_feature_attributes_wfs(
         value = str(value)
 
     except ValueError:
-        raise Exception("Unable to cast attribute/filter to string")
+        raise Exception("Unable to cast attribute/filter to string.")
 
     filter_request = PropertyIsLike(propertyname=attribute, literal=value, wildCard="*")
     filterxml = etree.tostring(filter_request.toXML()).decode("utf-8")
@@ -280,8 +320,8 @@ def get_raster_wcs(
             timeout=120,
         )
 
-    except Exception as e:
-        raise Exception(e)
+    except Exception:
+        raise
 
     data = resp.read()
 
@@ -367,9 +407,12 @@ def hydrobasins_aggregate(gdf: pd.DataFrame) -> pd.DataFrame:
 
 
 def select_hybas_domain(
-    bbox: Tuple[
-        Union[int, float], Union[int, float], Union[int, float], Union[int, float]
-    ]
+    bbox: Optional[
+        Tuple[
+            Union[int, float], Union[int, float], Union[int, float], Union[int, float]
+        ]
+    ] = None,
+    point: Optional[Tuple[Union[int, float], Union[int, float]]] = None,
 ) -> str:
     """
     Provided a given coordinate or boundary box, return the domain name of the geographic region
@@ -377,14 +420,20 @@ def select_hybas_domain(
 
     Parameters
     ----------
-    bbox : tuple
+    bbox : Optional[Tuple[Union[float, int], Union[float, int], Union[float, int], Union[float, int]]]
       Geographic coordinates of the bounding box (left, down, right, up).
+    point : Optional[Tuple[Union[float, int], Union[float, int]]]
+      Geographic coordinates of an intersecting point (lon, lat).
 
     Returns
     -------
     str
       The domain that the coordinate falls within. Possible results: "na", "ar".
     """
+    if bbox and point:
+        raise NotImplementedError("Provide either 'bbox' or 'point'.")
+    if point:
+        bbox = point * 2
 
     for dom, fn in hybas_domains.items():
         with open(fn, "rb") as f:
@@ -439,12 +488,10 @@ def get_hydrobasins_location_wfs(
     coordinates: Tuple[
         Union[str, float, int],
         Union[str, float, int],
-        Union[str, float, int],
-        Union[str, float, int],
     ],
     domain: str = None,
     geoserver: str = GEO_URL,
-) -> bytes:
+) -> str:
     """Return features from the USGS HydroBASINS data set using bounding box coordinates.
 
     For geographic rasters, subsetting is based on WGS84 (Long, Lat) boundaries. If not geographic, subsetting based
@@ -452,7 +499,7 @@ def get_hydrobasins_location_wfs(
 
     Parameters
     ----------
-    coordinates : Tuple[Union[str, float, int], Union[str, float, int], Union[str, float, int], Union[str, float, int]]
+    coordinates : Tuple[Union[str, float, int], Union[str, float, int]]
       Geographic coordinates of the bounding box (left, down, right, up).
     domain : {"na", "ar"}
       The domain of the HydroBASINS data.
@@ -468,7 +515,10 @@ def get_hydrobasins_location_wfs(
     lakes = True
     level = 12
     layer = f"public:USGS_HydroBASINS_{'lake_' if lakes else ''}{domain}_lev{str(level).zfill(2)}"
-    data = _get_location_wfs(coordinates, layer=layer, geoserver=geoserver)
+    if not wfs_Point and not Intersects:
+        data = _get_location_wfs(bbox=coordinates * 2, layer=layer, geoserver=geoserver)
+    else:
+        data = _get_location_wfs(point=coordinates, layer=layer, geoserver=geoserver)
 
     return data
 
@@ -604,13 +654,11 @@ def get_hydro_routing_location_wfs(
     coordinates: Tuple[
         Union[int, float, str],
         Union[str, float, int],
-        Union[str, float, int],
-        Union[str, float, int],
     ],
     lakes: str,
     level: int = 12,
     geoserver: str = GEO_URL,
-) -> bytes:
+) -> str:
     """Return features from the hydro routing data set using bounding box coordinates.
 
     For geographic rasters, subsetting is based on WGS84 (Long, Lat) boundaries. If not geographic, subsetting based
@@ -618,7 +666,7 @@ def get_hydro_routing_location_wfs(
 
     Parameters
     ----------
-    coordinates : Tuple[Union[str, float, int], Union[str, float, int], Union[str, float, int], Union[str, float, int]]
+    coordinates : Tuple[Union[str, float, int], Union[str, float, int]]
       Geographic coordinates of the bounding box (left, down, right, up).
     lakes : {"1km", "all"}
       Query the version of dataset with lakes under 1km in width removed ("1km") or return all lakes ("all").
@@ -634,6 +682,10 @@ def get_hydro_routing_location_wfs(
 
     """
     layer = f"public:routing_{lakes}Lakes_{str(level).zfill(2)}"
-    data = _get_location_wfs(coordinates, layer=layer, geoserver=geoserver)
+
+    if not wfs_Point and not Intersects:
+        data = _get_location_wfs(bbox=coordinates * 2, layer=layer, geoserver=geoserver)
+    else:
+        data = _get_location_wfs(point=coordinates, layer=layer, geoserver=geoserver)
 
     return data
